###############################################
HPMCM: Heirarchical Pixel Multi-Catalog Matcher
###############################################

***********
Description
***********

`HPMCM` does multi-catalog cross matching by clustering sources from
individual catalogs using a heirarchical pixelization scheme.


.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   source/overview	     
   source/installation
     
.. toctree::
   :maxdepth: 2
   :caption: Contributing

   source/contributing

.. toctree::
   :maxdepth: 2
   :caption: Demonstrations
   
   demos


.. toctree::
   :maxdepth: 2
   :caption: Command line interface
   
   source/cli
   
   
.. toctree::
   :maxdepth: 3
   :caption: API

   api/hpmcm



